@@ -1,7 +1,7 @@
 `Pradfoc` <-
 function(A , MEC, GU, pscale, col)
   {
-    C = circle()
+    C = RPMG::circle()
     
     imageP(MEC$az1, MEC$dip1, MEC$rake1, SCALE=FALSE, UP=MEC$UP, col=col )
     
